@@ -1,9 +1,13 @@
 import win32com.client
+import psutil
 
 
 class COM:
     """COM Interface singleton implementation
 
+    The purpose of this class is to ensure that all objects refer
+    to a common instance of the program being interacted with.
+
     Program     | Prog ID
     ----------- | -------
     Solidworks  | SldWorks.Application
@@ -18,6 +22,10 @@ class COM:
 
     instance = None
 
+    # def process_exists(cls):
+    #     if "SLDWORKS.exe" not in [p.name() for p in psutil.process_iter()]:
+    #         cls.instance = None
+
     def __new__(cls, prog_id):
         if not cls.instance:
             cls.instance = cls.__COM(prog_id).com
